# OpenTTY 1.6.2 "The Resources Upgrade"

> This is OpenTTY, a terminal emulator  
> totally created in python that run a minimalist  
> version of shell into your system (Windows and Linux)  
> is supported by app.  

## OpenTTY 98

This is OpenTTY 98!  
In this release family the focus is implement some  
functions into OpenTTY and turn the users experience more  
cool and funny. If you found an issue, please report and  
help development team to turn the OpenTTY better.  
 
## Release Notes  

1. OpenTTY Free Runtime

This is the focus of this release, now is possible run PSH  
syntax in app call with `python -m opentty [command]`.  
 
It can run assets, open servers, etc. Only the Background  
Daemon isn't works 'cause it run while OpenTTY is running,  
meaning that with this Runtime it will execute normally.  

Other daemon that doesn't works is The PIPES Plugin, 'cause  
it saves the data in current cache session, what don't happens  
'cause it's call only and closes.  

2. Added assets `enchant` and `openpad`  
3. New HASH Security service in *Permission Plugin*  

Contributors: Mr. Lima  
GitHub Repository: https://github.com/fetuber4095/OpenTTY  

